@@ -27,6 +27,8 @@ from onedal.svm import SVC as onedal_SVC
 
 
 class SVC(sklearn_SVC, BaseSVC):
+    __doc__ = sklearn_SVC.__doc__
+
     @_deprecate_positional_args
     def __init__(self, *, C=1.0, kernel='rbf', degree=3, gamma='scale',
                  coef0=0.0, shrinking=True, probability=False,
@@ -41,6 +43,41 @@ class SVC(sklearn_SVC, BaseSVC):
             random_state=random_state)
 
     def fit(self, X, y, sample_weight=None):
+        """
+        Fit the SVM model according to the given training data.
+
+        Parameters
+        ----------
+        X : {array-like, sparse matrix} of shape (n_samples, n_features) \
+                or (n_samples, n_samples)
+            Training vectors, where `n_samples` is the number of samples
+            and `n_features` is the number of features.
+            For kernel="precomputed", the expected shape of X is
+            (n_samples, n_samples).
+
+        y : array-like of shape (n_samples,)
+            Target values (class labels in classification, real numbers in
+            regression).
+
+        sample_weight : array-like of shape (n_samples,), default=None
+            Per-sample weights. Rescale C per sample. Higher weights
+            force the classifier to put more emphasis on these points.
+
+        Returns
+        -------
+        self : object
+            Fitted estimator.
+
+        Notes
+        -----
+        If X and y are not C-ordered and contiguous arrays of np.float64 and
+        X is not a scipy.sparse.csr_matrix, X and/or y may be copied.
+
+        If X is a dense array, then the other methods will not support sparse
+        matrices as input.
+        """
+        if LooseVersion(sklearn_version) >= LooseVersion("1.0"):
+            self._check_feature_names(X, reset=True)
         dispatch(self, 'svm.SVC.fit', {
             'onedal': self.__class__._onedal_fit,
             'sklearn': sklearn_SVC.fit,
@@ -49,6 +86,24 @@ class SVC(sklearn_SVC, BaseSVC):
 
     @wrap_output_data
     def predict(self, X):
+        """
+        Perform regression on samples in X.
+
+        For an one-class model, +1 (inlier) or -1 (outlier) is returned.
+
+        Parameters
+        ----------
+        X : {array-like, sparse matrix} of shape (n_samples, n_features)
+            For kernel="precomputed", the expected shape of X is
+            (n_samples_test, n_samples_train).
+
+        Returns
+        -------
+        y_pred : ndarray of shape (n_samples,)
+            The predicted values.
+        """
+        if LooseVersion(sklearn_version) >= LooseVersion("1.0"):
+            self._check_feature_names(X, reset=False)
         return dispatch(self, 'svm.SVC.predict', {
             'onedal': self.__class__._onedal_predict,
             'sklearn': sklearn_SVC.predict,
@@ -56,6 +111,32 @@ class SVC(sklearn_SVC, BaseSVC):
 
     @property
     def predict_proba(self):
+        """
+        Compute probabilities of possible outcomes for samples in X.
+
+        The model need to have probability information computed at training
+        time: fit with attribute `probability` set to True.
+
+        Parameters
+        ----------
+        X : array-like of shape (n_samples, n_features)
+            For kernel="precomputed", the expected shape of X is
+            (n_samples_test, n_samples_train).
+
+        Returns
+        -------
+        T : ndarray of shape (n_samples, n_classes)
+            Returns the probability of the sample for each class in
+            the model. The columns correspond to the classes in sorted
+            order, as they appear in the attribute :term:`classes_`.
+
+        Notes
+        -----
+        The probability model is created using cross validation, so
+        the results can be slightly different than those obtained by
+        predict. Also, it will produce meaningless results on very small
+        datasets.
+        """
         self._check_proba()
         return self._predict_proba
 
@@ -72,6 +153,8 @@ class SVC(sklearn_SVC, BaseSVC):
 
     @wrap_output_data
     def decision_function(self, X):
+        if LooseVersion(sklearn_version) >= LooseVersion("1.0"):
+            self._check_feature_names(X, reset=False)
         return dispatch(self, 'svm.SVC.decision_function', {
             'onedal': self.__class__._onedal_decision_function,
             'sklearn': sklearn_SVC.decision_function,
